@@ -436,7 +436,7 @@ def main():
                                              formatter_class=CustomHelpFormatter,
                                              description='Add a zero branch length sister node to each current leaf node.')
     add_dummy_parser.add_argument('input_tree', help='input tree file')
-    add_dummy_parser.add_argument('output_tree', help='output tree file')
+    add_dummy_parser.add_argument('--taxonomy_file', help='add dummy nodes to taxonomy file')
     add_dummy_parser.add_argument('--silent', help='suppress output', action='store_true')
 
     # remove dummy nodes from curation tree
