@@ -24,6 +24,8 @@ from collections import defaultdict
 
 import dendropy
 
+from fuzzywuzzy import fuzz
+
 from biolib.common import check_file_exists, make_sure_path_exists, is_float
 from biolib.external.execute import check_dependencies
 from biolib.taxonomy import Taxonomy
@@ -62,7 +64,71 @@ class OptionsParser(object):
         check_file_exists(options.input_taxonomy)
 
         taxonomy = Taxonomy().read(options.input_taxonomy)
+        
+        # identify cases where root of child is highly similar to,
+        # but not identical to root of parent
+        # (e.g. f__Defferisomataceae; g__Deferrisoma -> missing 'f')
+        self.logger.info('Identifying parent-child taxa with sufficiently similar, but non-identical names to suggest a type.')
+        rank_suffix = {1: 'ota', 2: 'ia',  3: 'ales', 4: 'aceae', 5: None}
+        potential_issues = {}
+        for gid, taxa in taxonomy.items():
+            for rank_idx in range(1, 5):
+                # get parent name
+                parent = taxa[rank_idx][3:]
+                if '_' in parent:
+                    parent = parent[0:parent.rfind('_')]
+                    
+                if not parent.endswith(rank_suffix[rank_idx]):
+                    continue
+                
+                parent_root = parent.replace(rank_suffix[rank_idx], '')
+                
+                # get child name
+                child = taxa[rank_idx+1][3:]
+                if '_' in child:
+                    child = child[0:child.rfind('_')]
+                    
+                if rank_suffix[rank_idx+1]:
+                    if not child.endswith(rank_suffix[rank_idx+1]):
+                        continue
+                    child_root = child.replace(rank_suffix[rank_idx+1], '')
+                else:
+                    # genera have no fixed suffix
+                    child_root = child
+                    
+                # limit roots to shortest string as trailing characters
+                # often mismatch
+                # (e.g.  f__Streptomycetaceae -> Streptomycet;
+                #        g__Streptomyces -> Streptomyces)
+                min_root_len = min(len(parent_root), len(child_root))
+                parent_root = parent_root[0:min_root_len]
+                child_root = child_root[0:min_root_len]
+                
+                fuzzy_score = fuzz.ratio(parent_root, child_root)
+                prefix_score = 0
+                for idx in range(min_root_len):
+                    if parent_root[idx] != child_root[idx]:
+                        break
+                        
+                    prefix_score += 1
+                prefix_score = int(float(prefix_score)*100 / min_root_len)
 
+                if (fuzzy_score != 100 and fuzzy_score >= 75 
+                    and prefix_score != 100 and prefix_score <= 50 and prefix_score != 0):
+                    potential_issues['{}#{}'.format(parent, child)] = (parent_root, child_root, fuzzy_score, prefix_score)
+
+        print(' - identified {:,} potential issues'.format(len(potential_issues)))
+        if len(potential_issues) > 0:
+            for conflict, tokens in potential_issues.items():
+                parent, child = conflict.split('#')
+                parent_root, child_root, fuzzy_score, prefix_score = tokens
+                print(' - {} {}: fuzzy score = {}, prefix score = {}'.format(
+                        parent,
+                        child,
+                        fuzzy_score,
+                        prefix_score))
+
+        # perform standard taxonomy file checks
         p = CheckTaxonomyFile()
         p.check(taxonomy,
                 check_prefixes=True,
